@@ -17,16 +17,24 @@ from wpwatcher.db import WPWatcherDataBase
 from wpwatcher.daemon import WPWatcherDaemon
 
 class WPWatcherCLI():
+    """Main program class"""
+
     def __init__(self):
+        """Main program entrypoint"""
+        
+        # Parse arguments
         args=self.parse_args()
+        # Init logger with CLi arguments
         init_log(args.verbose, args.quiet)
         # If template conf , print and exit
         if args.template_conf: self.template_conf()
+        # Print "banner"
         log.info("WPWatcher -  Automating WPscan to scan and report vulnerable Wordpress sites")
         # If version, print and exit
         if args.version: self.verion()
         # Init WPWatcher obhect and dump reports
         if args.wprs!=False: self.wprs(args.wprs, args.daemon)
+        
         # Read config
         configuration=self.build_config_cli(args)
         
@@ -44,39 +52,40 @@ class WPWatcherCLI():
             
     @staticmethod
     def wprs(filepath=None, daemon=False):
+        """Generate JSON file database summary"""
         db=WPWatcherDataBase(filepath, daemon=daemon)
         print(results_summary(db._data))
         exit(0)
+
     @staticmethod
     def verion():
+        """Print version and contributors"""
         log.info("Version:\t\t%s"%VERSION)
         log.info("Authors:\t\t%s"""%AUTHORS)
         exit(0)
+
     @staticmethod
     def template_conf():
+        """Print template configuration"""
         print(WPWatcherConfig.TEMPLATE_FILE)
         exit(0)
 
-    # Arguments can overwrite config file values
     @staticmethod
     def parse_args():
+        """Parse CLI arguments, arguments can overwrite config file values"""
+
         parser = argparse.ArgumentParser(description="""WordPress Watcher is a Python wrapper for WPScan that manages scans on multiple sites and reports by email.
     Some config arguments can be passed to the command.
     It will overwrite previous values from config file(s).
     Check %s for more informations."""%(GIT_URL))
-        parser.add_argument('--conf', '-c', metavar='File path', help="""The script * must read a configuration file to set mail server settings, WPScan path and other options *.     
-    If no config file is found, mail server settings will have default values.  
-    Setup mail server settings and turn on `send_email_report` in the config file if you want to receive reports.  
-    You can specify multiple files `--conf File path [File path ...]`. Will overwrites the keys with each successive file.
-    If not specified with `--conf` parameter, will try to load config from file `~/.wpwatcher/wpwatcher.conf`, `~/wpwatcher.conf` and `./wpwatcher.conf`.
-    All options can be missing from config file.\n\n""", nargs='+', default=None)
-        parser.add_argument('--template_conf', '--tmpconf', help="""Print a template config file.
-    Use `wpwatcher --template_conf > ~/.wpwatcher/wpwatcher.conf && vim ~/.wpwatcher/wpwatcher.conf` to create (or overwrite) and edit the new default config file.""", action='store_true')
-        parser.add_argument('--version', '-V', help="Print WPWatcher version", action='store_true')
-        parser.add_argument('--wprs', metavar="Path to json file", help="Print database (wp_reports in config) summary. Leave path blank to find default file. Can be used with --daemon to print default daemon databse.", nargs='?', default=False)
+        parser.add_argument('--conf', '-c', metavar='File path', help="""Configuration file. You can specify multiple files, it will overwrites the keys with each successive file.
+    If not specified, will try to load config from file `~/.wpwatcher/wpwatcher.conf`, `~/wpwatcher.conf` and `./wpwatcher.conf`.
+    All options can be missing from config file.""", nargs='+', default=None)
+        parser.add_argument('--template_conf', '--tmpconf', help="""Print a template config file.""", action='store_true')
+        
         # Declare arguments that will overwrite config options
         parser.add_argument('--wp_sites', '--url', metavar="URL", help="Site(s) to scan, you can pass multiple values", nargs='+', default=None)
-        parser.add_argument('--wp_sites_list', '--urls', metavar="File path", help="Read URLs from a text file. File must contain one URL per line", default=None)
+        parser.add_argument('--wp_sites_list', '--urls', metavar="Path", help="Read URLs from a text file. File must contain one URL per line", default=None)
         parser.add_argument('--send_email_report', '--send', help="Enable email report sending", action='store_true')
         parser.add_argument('--email_to', '--em', metavar="Email", help="Email the specified receipent(s) you can pass multiple values", nargs='+', default=None)
         parser.add_argument('--send_infos', '--infos', help="Email INFO reports", action='store_true')
@@ -86,31 +95,42 @@ class WPWatcherCLI():
         parser.add_argument('--api_limit_wait', '--wait', help="Sleep 24h if API limit reached", action='store_true')
         parser.add_argument('--daemon',  help="Loop and scan for ever", action='store_true')
         parser.add_argument('--daemon_loop_sleep','--loop', metavar='Time string', help="Time interval to sleep in daemon loop")
-        parser.add_argument('--wp_reports', '--reports', metavar="File path", help="Database Json file", default=None)
-        parser.add_argument('--resend_emails_after','--resend', metavar="Time string", help="Minimum time interval to resend email reports")
+        parser.add_argument('--wp_reports', '--reports', metavar="Path", help="Database Json file", default=None)
+        parser.add_argument('--resend_emails_after','--resend', metavar="Time string", help="Minimum time interval to resend email report with same status")
         parser.add_argument('--asynch_workers','--workers', metavar="Number", help="Number of asynchronous workers", type=int)
-        parser.add_argument('--log_file','--log', metavar="File path", help="Logfile replicates all output with timestamps")
+        parser.add_argument('--log_file','--log', metavar="Path", help="Logfile replicates all output with timestamps")
         parser.add_argument('--follow_redirect','--follow',  help="Follow site redirection if causes WPscan failure", action='store_true')
-        parser.add_argument('--wpscan_output_folder','--wpout', metavar="Folder path", help="Write all WPScan results in sub directories 'info', 'warning', 'alert' and 'error'")
+        parser.add_argument('--wpscan_output_folder','--wpout', metavar="Path", help="Write all WPScan results in sub directories 'info', 'warning', 'alert' and 'error'")
         parser.add_argument('--wpscan_args','--wpargs', metavar='Arguments', help="WPScan arguments as string. See 'wpscan --help' for more infos")
         parser.add_argument('--false_positive_strings','--fpstr', metavar='String', help='False positive strings, you can pass multiple values', nargs='+', default=None)
         parser.add_argument('--prescan_without_api_token','--prescan', help='Scan without API token first and use API token on sites that triggered warnings', action='store_true')
         parser.add_argument('--verbose', '-v', help="Verbose output, print WPScan raw output and parsed WPScan results.", action='store_true')
         parser.add_argument('--quiet', '-q', help="Print only errors and WPScan ALERTS", action='store_true')
+
+        parser.add_argument('--version', '-V', help="Print WPWatcher version", action='store_true')
+        parser.add_argument('--wprs', metavar="Path", help="Print database (wp_reports in config) summary. Leave path blank to find default file. Can be used with --daemon to print default daemon databse.", nargs='?', default=False)
+
         args = parser.parse_args()
         return(args)
 
-    # Assemble the config dict from args and from file
     @staticmethod
     def build_config_cli(args):
-        args=vars(args) if hasattr(args, '__dict__') and not type(args)==dict else args
+        """Assemble the config dict from args and from file.  
+        Arguments:  
+        - 'args': Namespace from ArgumentParser.parse_args()
+        """
+
+        args=vars(args) #if hasattr(args, '__dict__') and not type(args)==dict else args
         # Configuration variables
         conf_files=args['conf'] if 'conf' in args else None
+        
         # Init config dict: read config files
-        configuration, files =WPWatcherConfig(files=conf_files).build_config()
-        if files: log.info("Load config file(s) : %s"%files)
-        conf_args={}
+        configuration, files = WPWatcherConfig(files=conf_files).build_config()
+        if files: 
+            log.info("Load config file(s) : %s"%files)
+        
         # Sorting out only args that matches config options and that are not None or False
+        conf_args={}
         for k in args: 
             if k in WPWatcherConfig.DEFAULT_CONFIG.keys() and args[k]:
                 conf_args.update({k:args[k]})  
@@ -122,12 +142,24 @@ class WPWatcherCLI():
                 conf_args['wp_sites']= sites if 'wp_sites' not in conf_args else conf_args['wp_sites']+sites
 
         conf_args=WPWatcherCLI.adjust_special_cli_args(conf_args)
+
         # Overwrite with conf dict biult from CLI Args
-        if conf_args: configuration.update(conf_args)
+        if conf_args: 
+            for k in conf_args:
+                if k == "wpscan_args":
+                    # MAke sure to append new WPScan arguments after defaults
+                    configuration[k].extend(conf_args[k])
+                else:
+                    configuration[k]=conf_args[k]
+
         return configuration
 
     @staticmethod
     def adjust_special_cli_args(conf_args):
+        """Adjust special CLI arguments types.  
+        Arguments:  
+        - 'conf_args': Configuration dict with CLI parsed values only"""
+
         # Adjust special case of urls that are list of dict
         if 'wp_sites' in conf_args: conf_args['wp_sites']=[ {"url":site} for site in conf_args['wp_sites'] ]
         # Adjust special case of resend_emails_after
@@ -139,7 +171,9 @@ class WPWatcherCLI():
         return conf_args
 
 def main(): 
+    """Main program"""
     WPWatcherCLI()
 
+"""Main program if called with wpwatcher/cli.py"""
 if __name__ == '__main__':
     WPWatcherCLI()
\ No newline at end of file
